@@ -1,3 +1,12 @@
+from flextls._registry import Registry
+from flextls.__about__ import (
+    __author__, __copyright__, __email__, __license__, __summary__, __title__,
+    __uri__, __version__
+)
+
+
+registry = Registry()
+
 class ConnectionState(object):
     def __init__(self):
         self.entity = None
