@@ -14,8 +14,4 @@ class ChangeCipherSpec(Protocol):
                     255: None
                 }
             ),
-        ]
-
-    def dissect(self, data):
-        data = Protocol.dissect(self, data)
-        return data
+        ]
\ No newline at end of file
